@@ -64,12 +64,12 @@
     <message>
         <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
-        <translation type="unfinished"></translation>
+        <translation>Applica correzioni sistematiche consecutive all&apos;orologio hardware.</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
-        <translation type="unfinished"></translation>
+        <translation>Regolazione dello scarto</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="329"/>
@@ -99,12 +99,12 @@
     <message>
         <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiorna il fattore di scarto per l&apos;orologio hardware quando viene impostato.</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiorna lo scarto</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="374"/>
@@ -199,23 +199,23 @@
     <message>
         <location filename="../datetime.cpp" line="284"/>
         <source>Adjusting...</source>
-        <translation type="unfinished"></translation>
+        <translation>Sto regolando...</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="296"/>
         <location filename="../datetime.cpp" line="303"/>
         <source>System Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Orologio di sistema</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
-        <translation type="unfinished"></translation>
+        <translation>Il tempo %1 è stato trasferito al %2.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
-        <translation type="unfinished"></translation>
+        <translation>Il tempo %1 non può essere trasferito al %2.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="350"/>
@@ -281,7 +281,7 @@
     <message>
         <location filename="../datetime.cpp" line="646"/>
         <source>MX Date &amp; Time Help</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Data &amp; Ora Aiuto</translation>
     </message>
 </context>
 </TS>
